% Demo of Kaiser windows, showing effect of beta

% Set up response of basic FIR LPF
close all

a = 1;
wc = .4*pi;
N = 51;
n = -(N-1)/2:(N-1)/2;

%Time domain response
hd = (wc/pi)*sinc(n*wc/pi);

% Loop for Kaiser window parameters

for beta = 0:3:9,
w = kaiser(N,beta)';
subplot(3,1,1),stem(n,w,'linewidth',2)
ib = num2str(beta);
title(['Kaiser window, N = 51, Beta = ',ib])
xlabel('n','fontsize',14,'fontweight','bold')
ylabel('w[n]','fontsize',14,'fontweight','bold')


%Frequency domain response of Kaiser window
[K,W] = freqz(w,1 );
subplot(3,1,2),plot(W/pi,20*log10(abs(K)/abs(K(1))),'linewidth',2)
xlabel('\omega/\pi','fontsize',14,'fontweight','bold')
ylabel('|W(\omega)|, dB','fontsize',14,'fontweight','bold')
ymin = -40 - (beta*20/3);
axis([0 1 ymin 0])


% Final filter
h = hd.*w;
[H,W] = freqz(h,1 );
subplot(3,1,3),plot(W/pi,20*log10(abs(H)),'linewidth',2)
xlabel('\omega/\pi','fontsize',14,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',14,'fontweight','bold')
ymin = -40 - (beta*20/3);
axis([0 1 ymin 0])


pause
end

