%Demo of window FIR filtering using windows .....
% This version compares frequency response as a function of shape

close all

a = 1;
wc = .4*pi;
N = 51;
n = -(N-1)/2:(N-1)/2;

% First, freq response, one at a time:


% Rectangular window

window = boxcar(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'linewidth',2)
title('DTFT of rectangular window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Bartlett window

window = bartlett(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'linewidth',2)
title('DTFT of Bartlett window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Hanning window

window = hanning(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of Hanning window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Hamming window

window = hamming(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'linewidth',2)
title('DTFT of Hamming window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Blackman window

window = blackman(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'linewidth',2)
title('DTFT of Blackman window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Repeat, but superimposed:


% Rectangular window

window = boxcar(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'linewidth',2)
title('DTFT of rectangular window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
hold on
axis([0 1 -100 10]);
pause


% Bartlett window

window = bartlett(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'g','linewidth',2)
title('DTFT of Bartlett window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Hanning window

window = hanning(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H+eps)),'c','linewidth',2)
title('DTFT of Hanning window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Hamming window

window = hamming(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'r','linewidth',2)
title('DTFT of Hamming window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Blackman window

window = blackman(N);
[H,W] = freqz(window,1 );
H = H/max(abs(H));
plot(W/pi,20*log10(abs(H)),'m','linewidth',2)
title('DTFT of Blackman window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause
hold off


%Re-initializing to avoid memory overflows:

clear
a = 1;
wc = .4*pi;
N = 51;
n = -(N-1)/2:(N-1)/2;

%Time domain response
hd = (wc/pi)*sinc(n*wc/pi);
stem(n,hd,'linewidth',2)
title('h[n] for LPF with rectangular window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
pause


%Frequency domain responses

% Rectangular window
w = boxcar(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of LPF with rectangular window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause

% Bartlett window
w = bartlett(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of LPF with Bartlett window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause

% Hanning window
w = hanning(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of LPF with Hanning window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause

% Hamming window
w = hamming(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of LPF with Hamming window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause


% Blackman window
w = blackman(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of LPF with Blackman window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
pause



% and holding .....



% Rectangular window
w = boxcar(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'linewidth',2)
title('DTFT of LPF with rectangular window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
hold on
pause

% Bartlett window
w = bartlett(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'g','linewidth',2)
title('DTFT of LPF with Bartlett window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
hold on
pause

% Hanning window
w = hanning(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'c','linewidth',2)
title('DTFT of LPF with Hanning window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
hold on
pause

% Hamming window
w = hamming(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'r','linewidth',2)
title('DTFT of LPF with Hamming window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
hold on
pause


% Blackman window
w = blackman(N);
[H,W] = freqz(w'.*hd,1 );
plot(W/pi,20*log10(abs(H+eps)),'m','linewidth',2)
title('DTFT of LPF with Blackman window, N = 51','fontsize',14)
xlabel('\omega/\pi','fontsize',16,'fontweight','bold')
ylabel('|H(\omega)|, dB','fontsize',16,'fontweight','bold')
axis([0 1 -100 10]);
hold on
pause

